标签：测试文档
#向量语义相似度测试：
>Enter the SemanticSimilarity mode...
`>>药材`
`>>当归`
`words similarity: 1.0`
`>>药材有什么作用`
`>>当归有什么作用`
`words similarity: 1.0`
`>>竹笋`
`>>树`
`words similarity: 0.0`
`>>树木`
`>>竹笋`
`words similarity: 0.0`
`>>竹笋`
`>>竹子`
`words similarity: 1.0`
`>>青椒`
`>>竹笋`
`words similarity: 0.0`
`>>土豆`
`>>薯类`
`words similarity: 1.0`
`>>薯类`
`>>青椒`
`words similarity: 1.0`
